powered by
Add a schema definition
schema_add_def(x, name, value, overwrite = FALSE)
A modified SchemaDoc.
SchemaDoc
A SchemaDoc.
Definition name to add.
Schema fragment using the same list syntax accepted by schema_doc(), or a fragment produced by helpers such as schema_check(), to store in $defs.
schema_doc()
schema_check()
$defs
Logical flag indicating whether an existing definition of the same name should be replaced.
schema <- schema_doc(schema_check("string")) schema <- schema_add_def(schema, "text", schema_check("string")) schema names(as.list(schema)$`$defs`)
Run the code above in your browser using DataLab