Learn R Programming

schemate (version 0.1.0)

schema_add_field: Add a field schema to a container node

Description

Add a field schema to a container node

Usage

schema_add_field(x, name, field, path = "$", overwrite = FALSE)

Value

A modified SchemaDoc.

Arguments

x

A SchemaDoc.

name

Field name to add.

field

Schema fragment using the same list syntax accepted by schema_doc(), or a fragment produced by helpers such as schema_check().

path

Path to the target container node. Use $ for the root node. Bare field segments such as $id implicitly traverse container fields. Use $fields$id to write the explicit field path. Backtick-quote field names that contain path operators, for example $`a$b` .

overwrite

Logical flag indicating whether an existing field of the same name should be replaced.

Examples

Run this code
schema <- schema_doc(list(check = list(kind = "list")))
schema
schema <- schema_add_field(schema, "id", schema_check("int", lower = 1))
schema

schema_validate(schema, list(id = 1L), mode = "test")

Run the code above in your browser using DataLab