Schema fragment using the same list syntax accepted by
schema_doc(), or a fragment produced by helpers such as schema_check().
path
Path to the target container node. Use $ for the root node.
Bare field segments such as $id implicitly traverse container fields. Use
$fields$id to write the explicit field path. Backtick-quote field names
that contain path operators, for example $`a$b` .
overwrite
Logical flag indicating whether an existing field of the same
name should be replaced.